@@ -1,6 +1,27 @@
 import os, sys
 import shutil
 import matplotlib.pyplot as plt
+import numpy as np
+import torch
+
+def get_device(gpu_id=-1):
+    if gpu_id < 0:
+        return torch.device('cpu')
+    else:
+        return torch.device(f'cuda:{gpu_id}')
+
+def get_coloset_elem_dist(row, arr):
+    assert len(arr.shape) == 2
+    row = np.asarray(row)
+    dist = np.sum((arr - row) ** 2, axis=1, keepdims=True)
+    idx_min = dist.argmin(axis=0)[0]
+    return dist[idx_min], idx_min
+
+def get_row_index_in_arr(row, arr):
+    assert len(arr.shape) == 2
+    row = np.asarray(row)
+    min_dist, min_dist_idx = get_coloset_elem_dist(row, arr)
+    return min_dist_idx if min_dist < 1e-6 else False
 
 
 def make_path_if_not_exist(path):
@@ -39,3 +60,4 @@ def draw_confusion_matrix(y_pred, y_true):
     print('Recall: %.3f' % recall_score(y_true, y_pred))
     print('Accuracy: %.3f' % accuracy_score(y_true, y_pred))
     print('F1 Score: %.3f' % f1_score(y_true, y_pred))
+
